# Code de conduite du Contributeur Covenant

## Notre engagement

Nous, en tant que membres, contributeurs et leaders, nous engageons à faire de la participation à notre
communauté une expérience sans harcèlement pour tous, quel que soit l'âge, la taille
du corps, le handicap visible ou invisible, l'origine ethnique, les caractéristiques sexuelles, l'identité
et l'expression de genre, le niveau d'expérience, l'éducation, le statut socio-économique,
la nationalité, l'apparence personnelle, la race, la religion ou l'identité sexuelle
et l'orientation.

Nous nous engageons à agir et à interagir de manière à contribuer à une communauté ouverte, accueillante,
diverse, inclusive et saine.

## Nos normes

Exemples de comportement qui contribuent à un environnement positif pour notre
communauté incluent :

* Faire preuve d'empathie et de gentillesse envers les autres
* Être respectueux des opinions, points de vue et expériences différents
* Donner et accepter avec grâce les retours constructifs
* Accepter la responsabilité et présenter des excuses à ceux affectés par nos erreurs,
  et apprendre de l'expérience
* Se concentrer sur ce qui est le mieux, non seulement pour nous en tant qu'individus, mais pour
  l'ensemble de la communauté

Exemples de comportements inacceptables incluent :

* L'utilisation d'un langage ou d'imagerie sexualisés, et toute attention ou
  avance de nature sexuelle
* Le trollage, les commentaires insultants ou désobligeants, et les attaques personnelles ou politiques
* Le harcèlement en public ou en privé
* La publication d'informations privées d'autrui, telles qu'une adresse physique ou électronique,
  sans leur permission explicite
* Tout autre comportement qui pourrait raisonnablement être considéré comme inapproprié dans un
  cadre professionnel

## Responsabilités d'application

Les responsables de la communauté sont chargés de clarifier et de faire respecter nos normes de
comportement acceptable et prendront des mesures correctives appropriées et équitables en
réponse à tout comportement qu'ils jugent inapproprié, menaçant, offensant,
ou nuisible.

Les responsables de la communauté ont le droit et la responsabilité de supprimer, modifier ou rejeter
les commentaires, commits, code, modifications de wiki, problèmes et autres contributions qui ne sont pas
conformes à ce Code de conduite, et communiqueront les raisons des décisions de modération
lorsque cela est approprié.

## Portée

Ce Code de conduite s'applique dans tous les espaces communautaires, et s'applique également lorsqu'un
individu représente officiellement la communauté dans des espaces publics.
Des exemples de représentation de notre communauté incluent l'utilisation d'une adresse e-mail officielle,
la publication via un compte officiel sur les réseaux sociaux, ou le fait d'agir en tant que
représentant désigné lors d'un événement en ligne ou hors ligne.

## Application

Les cas de comportement abusif, de harcèlement ou autrement inacceptable peuvent être
signalés aux responsables de la communauté chargés de l'application à l'adresse
aw@funstory.ai .
Toutes les plaintes seront examinées et traitées rapidement et équitablement.

Tous les responsables de la communauté sont tenus de respecter la confidentialité et la sécurité du
signaleur de tout incident.

## Lignes directrices d'application

Les responsables de la communauté suivront ces Lignes directrices d'impact communautaire pour déterminer
les conséquences de toute action qu'ils jugent en violation de ce Code de conduite :

### 1. Correction

**Impact sur la communauté** : Utilisation d'un langage inapproprié ou tout autre comportement jugé non professionnel ou indésirable dans la communauté.

**Conséquence** : Un avertissement écrit et privé des responsables de la communauté, clarifiant la nature de la violation et expliquant pourquoi le comportement était inapproprié. Des excuses publiques peuvent être demandées.

### 2. Avertissement

**Impact sur la communauté** : Une violation via un incident unique ou une série d'actions.

**Conséquence** : Un avertissement avec des conséquences en cas de comportement persistant. Aucune interaction avec les personnes concernées, y compris les interactions non sollicitées avec celles chargées de faire respecter le Code de conduite, pendant une période spécifiée. Cela inclut d'éviter les interactions dans les espaces communautaires ainsi que les canaux externes comme les réseaux sociaux. La violation de ces conditions peut entraîner un bannissement temporaire ou permanent.

### 3. Bannissement temporaire

**Impact sur la communauté** : Une violation grave des normes de la communauté, incluant un comportement inapproprié persistant.

**Conséquence** : Un bannissement temporaire de toute forme d'interaction ou de communication publique avec la communauté pour une période spécifiée. Aucune interaction publique ou privée avec les personnes concernées, y compris des interactions non sollicitées avec ceux qui appliquent le Code de conduite, n'est autorisée pendant cette période. La violation de ces conditions peut entraîner un bannissement permanent.

### 4. Bannissement permanent

**Impact sur la communauté** : Démontrer un schéma de violation des normes de la communauté, incluant un comportement inapproprié persistant, le harcèlement d'un individu, ou de l'agressivité ou du dénigrement envers des groupes d'individus.

**Conséquence** : Un bannissement permanent de toute forme d'interaction publique au sein de la communauté.

## Attribution

Ce Code de conduite est adapté du [Contributor Covenant][homepage],
version 2.0, disponible à l'adresse
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Les Lignes directrices sur l'impact communautaire ont été inspirées par [l'échelle d'application du code de conduite de Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Pour les réponses aux questions courantes sur ce code de conduite, consultez la FAQ à l'adresse
https://www.contributor-covenant.org/faq. Des traductions sont disponibles sur
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>